/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.web.help;

import static dk.vajhoej.vms.call.lib.VMSCodes.LBR$C_READ;
import static dk.vajhoej.vms.call.lib.VMSCodes.LBR$C_TYP_HLP;

import java.io.UnsupportedEncodingException;

import dk.vajhoej.vms.call.VMS;
import dk.vajhoej.vms.call.VMSLibrary.Result;
import dk.vajhoej.vms.call.lib.LBRRTL.LBR_IDX;

/**
 * Class LBRWrapper encapsulates the dk.vajhoej.vms.call.lib.LBRRTL stuff from the VMSCALL apckage.
 */
public class LBRWrapper {
	private LBR_IDX hlb;
	/**
	 * Initialize.
	 * @throws UnsupportedEncodingException if character set problems
	 */
	public void init() throws UnsupportedEncodingException {
    	hlb = new LBR_IDX();
    	Result<Void> inires = hlb.LBR$INI_CONTROL(LBR$C_READ, LBR$C_TYP_HLP);
    	if(!VMS.isSuccess(inires.getStatus())) throw new RuntimeException("Error in call to LBR$INI_CONTROL");
    	Result<Void> openres = hlb.LBR$OPEN("SYS$HELP:HELPLIB.HLB");
    	if(!VMS.isSuccess(openres.getStatus())) throw new RuntimeException("Error in call to LBR$OPEN");
	}
	/**
	 * Get help text.
	 * @param topics topic tree
	 * @return help text
	 * @throws UnsupportedEncodingException if character set problems
	 */
	public String get(String[] topics) throws UnsupportedEncodingException {
    	Result<String> getres = hlb.LBR$GET_HELP(topics);
    	if(!VMS.isSuccess(getres.getStatus())) throw new RuntimeException("Error in call to LBR$GET_HELP");
    	return getres.getResult();
	}
	/**
	 * Close.
	 */
	public void close() {
    	Result<Void> closeres = hlb.LBR$CLOSE();
    	if(!VMS.isSuccess(closeres.getStatus())) throw new RuntimeException("Error in call to LBR$CLOSE");
	}
}

